import 'OdooConnector.dart';

class AuthenticateCallback {
  bool _isSuccess = false;
  late OdooResponse _response;
  late String _newSessionId;

  AuthenticateCallback(
      bool isSuccess, OdooResponse response, String newSessionId) {
    _isSuccess = isSuccess;
    _response = response;
    _newSessionId = newSessionId;
  }

  bool getSuccess() {
    return _isSuccess;
  }

  String getSessionId() {
    return _newSessionId;
  }

  OdooUser getUser() {
    return OdooUser().parse(_response, _newSessionId);
  }

  Map? getError() {
    return !_isSuccess ? _response.getError() : null;
  }
}

class OdooUser {
  late String name;
  late String sessionId;
  late int uid;
  late String database;
  late String username;
  late int companyId;
  late int partnerId;
  late String lang;
  late String tz;

  OdooUser parse(OdooResponse response, String sessionId) {
    if (!response.hasError()) {
      this.sessionId = sessionId;
      Map data = response.getResult();
      name = data['name'];
      uid = data['uid'];
      database = data['db'];
      username = data['username'];
      companyId = data['company_id'];
      partnerId = data['partner_id'];
      lang = data['user_context']['lang'];
      tz = data['user_context']['tz'];
    }
    return this;
  }

  @override
  String toString() {
    var map = {
      "name": name,
      "uid": uid,
      "partner_id": partnerId,
      "company_id": companyId,
      "username": username,
      "lang": lang,
      "timezone": tz,
      "database": database,
      "session_id": sessionId
    };
    return map.toString();
  }
}
